<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>ActionPackInternal</name>
    <message>
        <location filename="../actions/actionpackinternal/actionpackinternal.h" line="74"/>
        <source>Internal actions</source>
        <translation>Actions internes</translation>
    </message>
</context>
<context>
    <name>Actions::BeginProcedureDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="43"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="44"/>
        <source>The name of the procedure</source>
        <translation>Le nom de la procédure</translation>
    </message>
    <message>
        <source>End Procedure action cannot be found</source>
        <translation type="obsolete">Impossible de trouver la fin de la procédure</translation>
    </message>
</context>
<context>
    <name>Actions::CallProcedureDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="43"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="44"/>
        <source>The name of the procedure to call</source>
        <translation>Le nom de la procédure à appeler</translation>
    </message>
</context>
<context>
    <name>Actions::CodeDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="43"/>
        <source>Code</source>
        <translation>Code</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="44"/>
        <source>The code to evaluate</source>
        <translation>Le code à évaluer</translation>
    </message>
</context>
<context>
    <name>Actions::ConsoleDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="46"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="47"/>
        <source>The text to write</source>
        <translation>Le texte à écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="49"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="50"/>
        <source>The console output</source>
        <translation>Le type de sortie</translation>
    </message>
</context>
<context>
    <name>Actions::EndProcedureInstance</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/endprocedureinstance.h" line="42"/>
        <source>End procedure reached without a call</source>
        <translation>Fin de procédure atteint sans procédure appelée</translation>
    </message>
</context>
<context>
    <name>Actions::GotoDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="43"/>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="44"/>
        <source>The line (or label) to go to</source>
        <translation>La ligne (ou l&apos;étiquette) où aller</translation>
    </message>
</context>
<context>
    <name>Actions::LoopDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="46"/>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="47"/>
        <source>The line (or label) to go to</source>
        <translation>La ligne (ou l&apos;étiquette) où aller</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="49"/>
        <source>Count</source>
        <translation>Nombre de fois</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="50"/>
        <source>The number of times (evaluated the first time)</source>
        <translation>Le nombre de fois (évalué la première fois)</translation>
    </message>
    <message>
        <source>The amount of times (evaluated the first time)</source>
        <translation type="vanished">Le nombre de fois (évalué la première fois)</translation>
    </message>
</context>
<context>
    <name>Actions::PauseDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="48"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="49"/>
        <source>The duration of the pause</source>
        <translation>La durée de la pause</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="54"/>
        <source>Unit</source>
        <translation>Unité</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="55"/>
        <source>The pause duration unit</source>
        <translation>L&apos;unité de durée de pause</translation>
    </message>
    <message>
        <source> ms</source>
        <comment>milliseconds</comment>
        <translation type="obsolete"> ms</translation>
    </message>
</context>
<context>
    <name>Actions::PauseInstance</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.h" line="65"/>
        <source>Invalid pause duration</source>
        <translation>Durée de pause incorrecte</translation>
    </message>
</context>
<context>
    <name>Actions::TimeConditionDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="44"/>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="45"/>
        <source>The date to compare</source>
        <translation>La date à comparer</translation>
    </message>
    <message>
        <source>If before</source>
        <translation type="vanished">Si avant</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="47"/>
        <source>If in the past</source>
        <translation>Si dans le passé</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="48"/>
        <source>What to do if the date is in the past</source>
        <translation>Ce qui doit être fait si la date appartient au passé</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="50"/>
        <source>If now</source>
        <translation>Si maintenant</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="51"/>
        <source>What to do if the date is the current date</source>
        <translation>Ce qui doit être fait si la date est la date actuelle</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="53"/>
        <source>If in the future</source>
        <translation>Si dans le futur</translation>
    </message>
    <message>
        <source>If after</source>
        <translation type="vanished">Si après</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="54"/>
        <source>What to do if the date is in the future</source>
        <translation>Ce qui doit être fait si la date appartient au futur</translation>
    </message>
</context>
<context>
    <name>Actions::TimeConditionInstance</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditioninstance.h" line="48"/>
        <source>Invalid date</source>
        <translation>Date incorrecte</translation>
    </message>
</context>
<context>
    <name>Actions::VariableConditionDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="48"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="50"/>
        <source>The variable to compare</source>
        <translation>La variable à comparer</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="52"/>
        <source>Comparison</source>
        <translation>Comparaison</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="53"/>
        <source>The comparison</source>
        <translation>La comparaison</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="57"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="58"/>
        <source>The value</source>
        <translation>La valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="60"/>
        <source>If true</source>
        <translation>Si vrai</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="61"/>
        <source>What to do if the comparison result is true</source>
        <translation>Ce qui doit être fait si le résultat de la comparaison est vrai</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="63"/>
        <source>If false</source>
        <translation>Si faux</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="64"/>
        <source>What to do if the comparison result is false</source>
        <translation>Ce qui doit être fait si le résultat de la comparaison est faux</translation>
    </message>
    <message>
        <source>If equal</source>
        <translation type="obsolete">Si égal</translation>
    </message>
    <message>
        <source>What to do if the values are equal</source>
        <translation type="obsolete">Ce qui doit être fait si les valeurs sont égales</translation>
    </message>
    <message>
        <source>If different</source>
        <translation type="obsolete">Si différent</translation>
    </message>
    <message>
        <source>What to do if the values are different</source>
        <translation type="obsolete">Ce qui doit être fait si les valeurs sont différentes</translation>
    </message>
</context>
<context>
    <name>Actions::VariableConditionInstance</name>
    <message>
        <source>Null variable</source>
        <translation type="obsolete">Variable nulle</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.h" line="69"/>
        <source>Invalid variable</source>
        <translation>Variable invalide</translation>
    </message>
</context>
<context>
    <name>Actions::VariableDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="50"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="52"/>
        <source>The variable name</source>
        <translation>Le nom de la variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="67"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <source>The variable&apos;s new value</source>
        <translation type="obsolete">La nouvelle valeur de la variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="54"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="55"/>
        <source>The variable type</source>
        <translation>Le type de la variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="68"/>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="77"/>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="86"/>
        <source>The variables new value</source>
        <translation>La nouvelle valeur de la variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="76"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="85"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="88"/>
        <source>Conversion failed</source>
        <translation>Echec de convertion</translation>
    </message>
</context>
<context>
    <name>Actions::VariableInstance</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.h" line="82"/>
        <source>Cannot evaluate the value as an integer</source>
        <translation>Impossible d&apos;évaluer la valeur en tant que nombre entier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.h" line="93"/>
        <source>Cannot evaluate the value as a floating number</source>
        <translation>Impossible d&apos;évaluer la valeur en tant que nombre décimal</translation>
    </message>
</context>
<context>
    <name>ConsoleInstance::outputs</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoleinstance.cpp" line="28"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoleinstance.cpp" line="29"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoleinstance.cpp" line="30"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>PauseInstance::units</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.cpp" line="28"/>
        <source>Milliseconds</source>
        <translation>Millisecondes</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.cpp" line="29"/>
        <source>Seconds</source>
        <translation>Secondes</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.cpp" line="30"/>
        <source>Minutes</source>
        <translation>Minutes</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.cpp" line="31"/>
        <source>Hours</source>
        <translation>Heures</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.cpp" line="32"/>
        <source>Days</source>
        <translation>Jours</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="48"/>
        <source>Code</source>
        <translation>Code</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="51"/>
        <source>Evaluates some code</source>
        <translation>Évalue du code</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Quitter</translation>
    </message>
    <message>
        <source>Exit Actionaz</source>
        <translation type="obsolete">Quitte Actionaz</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="47"/>
        <source>Goto</source>
        <translation>Aller à</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="50"/>
        <source>Go to a script line</source>
        <translation>Va à une ligne du script</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="55"/>
        <source>Loop</source>
        <translation>Boucle</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="58"/>
        <source>Go to a script line a specific number of times</source>
        <translation>Va à une ligne du script un certain nombre de fois</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/noopdefinition.h" line="44"/>
        <source>No-op</source>
        <translation>Aucune opération</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/noopdefinition.h" line="47"/>
        <source>Does nothing</source>
        <translation>Ne fait rien</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="60"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="63"/>
        <source>Pauses the script execution</source>
        <translation>Met en pause l&apos;exécution du script</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/stopdefinition.h" line="44"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/stopdefinition.h" line="47"/>
        <source>Stop the script execution</source>
        <translation>Stoppe l&apos;exécution du script</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="58"/>
        <source>Time condition</source>
        <translation>Condition temporelle</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="61"/>
        <source>Check the current date time and do some action</source>
        <translation>Vérifie la date actuelle et effectue une action</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="67"/>
        <source>Variable condition</source>
        <translation>Condition de variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="70"/>
        <source>Check the value of a variable and do some action</source>
        <translation>Vérifie la valeur d&apos;une variable et effectue une action</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="91"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="94"/>
        <source>Set the value of a variable</source>
        <translation>Change la valeur d&apos;une variable</translation>
    </message>
    <message>
        <source>Equal (=)</source>
        <translation type="obsolete">Égal (=)</translation>
    </message>
    <message>
        <source>Different (!=)</source>
        <translation type="obsolete">Différent (!=)</translation>
    </message>
    <message>
        <source>Inferior (&lt;)</source>
        <translation type="obsolete">Inférieur (&lt;)</translation>
    </message>
    <message>
        <source>Superior (&gt;)</source>
        <translation type="obsolete">Supérieur (&gt;)</translation>
    </message>
    <message>
        <source>Inferior or equal (&lt;=)</source>
        <translation type="obsolete">Inférieur ou égal (&lt;=)</translation>
    </message>
    <message>
        <source>Superior or equal (&gt;=)</source>
        <translation type="obsolete">Supérieur ou égal (&gt;=)</translation>
    </message>
    <message>
        <source>Contains</source>
        <translation type="obsolete">Contient</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="55"/>
        <source>Console</source>
        <translation>Console</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="58"/>
        <source>Write an entry in the console</source>
        <translation>Écrit une entrée dans la console</translation>
    </message>
    <message>
        <source>Exit Actionaz</source>
        <comment>action name: to exit</comment>
        <translation type="obsolete">Quitter Actionaz</translation>
    </message>
    <message>
        <source>Exit Actionaz</source>
        <comment>action description: this exits</comment>
        <translation type="obsolete">Quitte Actionaz</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="48"/>
        <source>Begin procedure</source>
        <translation>Début de procédure</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="51"/>
        <source>Declares a new procedure</source>
        <translation>Déclare une nouvelle procédure</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="47"/>
        <source>Call procedure</source>
        <translation>Appel de procédure</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="50"/>
        <source>Calls a procedure</source>
        <translation>Appelle une procédure</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/endproceduredefinition.h" line="44"/>
        <source>End procedure</source>
        <translation>Fin de procédure</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/endproceduredefinition.h" line="47"/>
        <source>Ends a procedure</source>
        <translation>Termine une procédure</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/exitdefinition.h" line="44"/>
        <source>Exit Actiona</source>
        <comment>action name: to exit</comment>
        <translation>Quitter Actiona</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/exitdefinition.h" line="47"/>
        <source>Exit Actiona</source>
        <comment>action description: this exits</comment>
        <translation>Quitte Actiona</translation>
    </message>
</context>
<context>
    <name>VariableConditionInstance::comparisons</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="28"/>
        <source>Equal (=)</source>
        <translation>Égal (=)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="29"/>
        <source>Different (!=)</source>
        <translation>Différent (!=)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="30"/>
        <source>Inferior (&lt;)</source>
        <translation>Inférieur (&lt;)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="31"/>
        <source>Superior (&gt;)</source>
        <translation>Supérieur (&gt;)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="32"/>
        <source>Inferior or equal (&lt;=)</source>
        <translation>Inférieur ou égal (&lt;=)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="33"/>
        <source>Superior or equal (&gt;=)</source>
        <translation>Supérieur ou égal (&gt;=)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="34"/>
        <source>Contains</source>
        <translation>Contient</translation>
    </message>
</context>
<context>
    <name>VariableInstance::types</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="28"/>
        <source>String</source>
        <translation>Chaîne de caractères</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="29"/>
        <source>Integer</source>
        <translation>Nombre entier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="30"/>
        <source>Float</source>
        <translation>Nombre décimal</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="31"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="32"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="33"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
</context>
</TS>
